==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicSliderUI__24ComponentHandler.h <==
// public class javax.swing.plaf.basic.BasicSliderUI$ComponentHandler

// class file dependencies
// @dep_class 40238674ada23301 java_awt_event_ComponentAdapter
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c22ec487d6d70e05 javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler

// header file dependencies
// @dep_header java_awt_event_ComponentAdapter

#include "java/awt/event/ComponentAdapter.h"

#ifndef _JC_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler_H_
#define _JC_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler_H_

// Forward structure declarations
struct _jc_java_awt_event_ComponentEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicSliderUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$refs	_jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$object	_jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$vmethods	_jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$vtable	_jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$vtype	_jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$method$_init$25832a2a9f17a095(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$object *, struct _jc_javax_swing_plaf_basic_BasicSliderUI$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$method$componentResized$ac5fcd90b88c07ec(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$object *, struct _jc_java_awt_event_ComponentEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$method_info$componentResized$ac5fcd90b88c07ec;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$vmethods {
	void	(*componentResized$ac5fcd90b88c07ec)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$object *, struct _jc_java_awt_event_ComponentEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_ComponentAdapter$vmethods	java_awt_event_ComponentAdapter;
	_jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$vmethods	javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicSliderUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$refs {
    _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$sub_refs	javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler;
    _jc_java_awt_event_ComponentAdapter$sub_refs	java_awt_event_ComponentAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_ComponentAdapter$sub_nonrefs	java_awt_event_ComponentAdapter;
    _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$sub_nonrefs	javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$object {
	_jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$vtype _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicSliderUI__24ComponentHandler.h <==
// public class javax.swing.plaf.basic.BasicSliderUI$ComponentHandler

// class file dependencies
// @dep_class 40238674ada23301 java_awt_event_ComponentAdapter
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c22ec487d6d70e05 javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler

// header file dependencies
// @dep_header java_awt_event_ComponentAdapter

#include "java/awt/event/ComponentAdapter.h"

#ifndef _JC_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler_H_
#define _JC_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler_H_

// Forward structure declarations
struct _jc_java_awt_event_ComponentEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicSliderUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$refs	_jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$object	_jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$vmethods	_jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$vtable	_jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$vtype	_jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$method$_init$25832a2a9f17a095(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$object *, struct _jc_javax_swing_plaf_basic_BasicSliderUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$method$componentResized$ac5fcd90b88c07ec(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$object *, struct _jc_java_awt_event_ComponentEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$method_info$componentResized$ac5fcd90b88c07ec;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$vmethods {
	void	(*componentResized$ac5fcd90b88c07ec)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$object *, struct _jc_java_awt_event_ComponentEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_ComponentAdapter$vmethods	java_awt_event_ComponentAdapter;
	_jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$vmethods	javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicSliderUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$refs {
    _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$sub_refs	javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler;
    _jc_java_awt_event_ComponentAdapter$sub_refs	java_awt_event_ComponentAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_ComponentAdapter$sub_nonrefs	java_awt_event_ComponentAdapter;
    _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$sub_nonrefs	javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$object {
	_jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$vtype _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicSliderUI__24ComponentHandler_H_ */
